Face EEVEE
==========

.. image:: https://img.shields.io/pypi/v/face_eevee.svg
    :target: https://pypi.python.org/pypi/face_eevee
    :alt: Latest PyPI version

.. image:: https://travis-ci.com/alexisfcote/face_eevee.svg?branch=master
    :target: https://travis-ci.com/alexisfcote/face_eevee
    :alt: Latest Travis-ci build

Early test of eos lib for the EEVEE plateform. Fit a facemesh on facial landmarks detected by the webcam 0

Usage
-----
face_eevee.exe

quit with 'q' or 'esc'

Installation
------------
pip install face_eevee

Requirements
^^^^^^^^^^^^
imutils 
numpy 
opencv-python 
eos-py 
dlib
matplotlib

Compatibility
-------------
python>=3.5

Authors
-------

`face_eevee` was written by `Alexis Fortin-Cote <alexisfcote@gmail.com>`_.
